<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://chainwire.org
 * @since             1.0.1
 * @package           ChainWire
 *
 * @wordpress-plugin
 * Plugin Name:       ChainWire Integration
 * Plugin URI:        https://chainwire.org/chain-wire-uri/
 * Description:       Integrate Your Blog With ChainWire Platform
 * Version:           1.0.6
 * Author:            ChainWire.org
 * Author URI:        https://chainwire.org/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       chain-wire
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'CHAIN_WIRE_INTEGRATION_PLUGIN', '1.0.6' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-chain-wire-activator.php
 */
function activate_chain_wire_plugin() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-chain-wire-activator.php';
	ChainWireActivator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-chain-wire-deactivator.php
 */
function deactivate_chain_wire_plugin() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-chain-wire-deactivator.php';
	ChainWireDeactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_chain_wire_plugin' );
register_deactivation_hook( __FILE__, 'deactivate_chain_wire_plugin' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-chain-wire.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_chain_wire_plugin() {

	$plugin = new ChainWire();
	$plugin->run();

}
run_chain_wire_plugin();
